=======
Twitter
=======

.. automodule:: orangecontrib.text.twitter


.. autoclass:: orangecontrib.text.twitter.Credentials
   :members:
   :special-members: __init__


.. autoclass:: orangecontrib.text.twitter.TwitterAPI
   :members:
   :special-members: __init__

